from random import randrange
import sys
import click

def generate(length, option):
    # type options - 1 - alphabetic lowercase, 2 - alphabetic mixed, 3 - alphanumeric, 4 - alphanumeric + special characters
    uppercase = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'
    lowercase = 'abcdefghijklmnopqrstuvwxyz'
    numbers = '0123456789'
    specialcharacters = '~`!@#$%^&*-_+=/?.'
    password = ''
    for _ in range(length):
        string = lowercase
        if option == 2:
            string = string + uppercase
        if option == 3:
            string = string + uppercase + numbers
        if option == 4:
            string = string + uppercase + numbers + specialcharacters
        stringlength = len(string)
        password += string[randrange(stringlength)]
    click.echo(password)


import click
from app import application

CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])

@click.group(context_settings=CONTEXT_SETTINGS)
def cli():
    pass

@cli.command()
@click.option('-l', '--length', type=int, help='Length of password to be generated')
@click.option('-o', '--option', type=click.Choice(['1', '2', '3', '4']), default = '4',
    help='''Options\n
    1 - alphabetic lowercase\n
    2 - alphabetic both cases\n
    3 - alphanumeric\n
    4 - alphanumeric + special characters'''
)
def generate(length, option):
    """generates a random password of length and type"""
    application.generate(int(length), int(option))
